==> org.opennms.features.api-layer-24.0.0-20181106.232334-9-sources.jar: org/opennms/features/apilayer/dao/NodeDaoImpl.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2018 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2018 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.features.apilayer.dao;

import java.util.Comparator;
import java.util.List;
import java.util.Objects;
import java.util.stream.Collectors;

import org.opennms.core.criteria.CriteriaBuilder;
import org.opennms.features.apilayer.utils.ModelMappers;
import org.opennms.integration.api.v1.dao.NodeDao;
import org.opennms.integration.api.v1.model.Node;
import org.opennms.netmgt.dao.api.SessionUtils;
import org.opennms.netmgt.model.OnmsNode;

import com.google.common.collect.Lists;

public class NodeDaoImpl implements NodeDao {

    private final org.opennms.netmgt.dao.api.NodeDao nodeDao;
    private final SessionUtils sessionUtils;

    public NodeDaoImpl(org.opennms.netmgt.dao.api.NodeDao nodeDao, SessionUtils sessionUtils) {
        this.nodeDao = Objects.requireNonNull(nodeDao);
        this.sessionUtils = Objects.requireNonNull(sessionUtils);
    }

    @Override
    public List<Node> getNodes() {
        return sessionUtils.withTransaction(() ->
                nodeDao.findAll().stream().map(ModelMappers::toNode).collect(Collectors.toList()));
    }

    @Override
    public Long getNodeCount() {
        final CriteriaBuilder criteriaBuilder = new CriteriaBuilder(OnmsNode.class);
        return (long)nodeDao.countMatching(criteriaBuilder.toCriteria());
    }

    @Override
    public List<Integer> getNodeIds() {
        return Lists.newArrayList(nodeDao.getNodeIds());
    }

    @Override
    public Node getNodeByCriteria(String nodeCriteria) {
        return ModelMappers.toNode(nodeDao.get(nodeCriteria));
    }

    @Override
    public Node getNodeById(Integer nodeId) {
        return sessionUtils.withTransaction(() -> ModelMappers.toNode(nodeDao.get(nodeId)));
    }

    @Override
    public Node getNodeByLabel(String nodeLabel) {
        return sessionUtils.withTransaction(() -> ModelMappers.toNode(nodeDao.findByLabel(nodeLabel).stream()
                .min(Comparator.comparingInt(OnmsNode::getId))
                .orElse(null)));
    }

    @Override
    public Node getNodeByForeignSourceAndForeignId(String foreignSource, String foreignId) {
        return sessionUtils.withTransaction(() ->
                ModelMappers.toNode(nodeDao.findByForeignId(foreignSource, foreignId)));
    }
}

==> org.opennms.features.api-layer-24.0.0-20190122.225206-63-sources.jar: org/opennms/features/apilayer/dao/NodeDaoImpl.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2018 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2018 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.features.apilayer.dao;

import java.util.Comparator;
import java.util.List;
import java.util.Objects;
import java.util.stream.Collectors;

import org.opennms.core.criteria.CriteriaBuilder;
import org.opennms.features.apilayer.utils.ModelMappers;
import org.opennms.integration.api.v1.dao.NodeDao;
import org.opennms.integration.api.v1.model.Node;
import org.opennms.netmgt.dao.api.SessionUtils;
import org.opennms.netmgt.model.OnmsNode;

import com.google.common.collect.Lists;

public class NodeDaoImpl implements NodeDao {

    private final org.opennms.netmgt.dao.api.NodeDao nodeDao;
    private final SessionUtils sessionUtils;

    public NodeDaoImpl(org.opennms.netmgt.dao.api.NodeDao nodeDao, SessionUtils sessionUtils) {
        this.nodeDao = Objects.requireNonNull(nodeDao);
        this.sessionUtils = Objects.requireNonNull(sessionUtils);
    }

    @Override
    public List<Node> getNodes() {
        return sessionUtils.withReadOnlyTransaction(() ->
                nodeDao.findAll().stream().map(ModelMappers::toNode).collect(Collectors.toList()));
    }

    @Override
    public Long getNodeCount() {
        final CriteriaBuilder criteriaBuilder = new CriteriaBuilder(OnmsNode.class);
        return sessionUtils.withReadOnlyTransaction(() -> (long)nodeDao.countMatching(criteriaBuilder.toCriteria()));
    }

    @Override
    public List<Integer> getNodeIds() {
        return sessionUtils.withReadOnlyTransaction(() -> Lists.newArrayList(nodeDao.getNodeIds()));
    }

    @Override
    public Node getNodeByCriteria(String nodeCriteria) {
        return sessionUtils.withReadOnlyTransaction(() -> ModelMappers.toNode(nodeDao.get(nodeCriteria)));
    }

    @Override
    public Node getNodeById(Integer nodeId) {
        return sessionUtils.withReadOnlyTransaction(() -> ModelMappers.toNode(nodeDao.get(nodeId)));
    }

    @Override
    public Node getNodeByLabel(String nodeLabel) {
        return sessionUtils.withReadOnlyTransaction(() -> ModelMappers.toNode(nodeDao.findByLabel(nodeLabel).stream()
                .min(Comparator.comparingInt(OnmsNode::getId))
                .orElse(null)));
    }

    @Override
    public Node getNodeByForeignSourceAndForeignId(String foreignSource, String foreignId) {
        return sessionUtils.withReadOnlyTransaction(() ->
                ModelMappers.toNode(nodeDao.findByForeignId(foreignSource, foreignId)));
    }
}
